@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42 2003/02/10 11:56:44 joern Exp $
+# $Id: Config.pm,v 1.42.2.1 2003/02/15 09:36:24 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -48,7 +48,7 @@ my %CONFIG_PARAMETER = (
 	},
 	thumbnail_factor => {
 		type  => 'number',
-		value => 5,
+		value => 4.2,
 	},
 	dvd_device => {
 		label => "DVD device",
@@ -534,7 +534,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42 2003/02/10 11:56:44 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.1 2003/02/15 09:36:24 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
